"use strict";

/**
 * Available loader indicator names for LoaderKit
 */

// Common indicators available on both iOS and Android

// iOS-only indicators (not available on Android)

// All available indicator names

/**
 * Helper arrays for runtime checks and platform detection
 */
export const COMMON_INDICATORS = ['BallPulse', 'BallGridPulse', 'BallClipRotate', 'SquareSpin', 'BallClipRotatePulse', 'BallClipRotateMultiple', 'BallPulseRise', 'BallRotate', 'CubeTransition', 'BallZigZag', 'BallZigZagDeflect', 'BallTrianglePath', 'BallScale', 'LineScale', 'LineScaleParty', 'BallScaleMultiple', 'BallPulseSync', 'BallBeat', 'LineScalePulseOut', 'LineScalePulseOutRapid', 'BallScaleRipple', 'BallScaleRippleMultiple', 'BallSpinFadeLoader', 'LineSpinFadeLoader', 'TriangleSkewSpin', 'Pacman', 'BallGridBeat', 'SemiCircleSpin', 'Orbit', 'AudioEqualizer', 'BallDoubleBounce'];
export const IOS_ONLY_INDICATORS = ['BallRotateChase', 'CircleStrokeSpin'];
export const ALL_INDICATORS = [...COMMON_INDICATORS, ...IOS_ONLY_INDICATORS];

/**
 * Type guard to check if an indicator is available on the current platform
 */
export const isIndicatorAvailableOnPlatform = (indicator, platform) => {
  if (platform === 'ios') {
    return true; // All indicators are available on iOS
  }

  // On Android, only common indicators are available
  return COMMON_INDICATORS.includes(indicator);
};

/**
 * Get all available indicators for a specific platform
 */
export const getAvailableIndicators = platform => {
  if (platform === 'ios') {
    return ALL_INDICATORS;
  }
  return COMMON_INDICATORS;
};
//# sourceMappingURL=types.js.map